@@ -15,6 +15,11 @@ class BaseEnum(str, Enum, metaclass=BaseMetadataEnum):
     """Base enum class."""
 
 
+class Language(BaseEnum):
+    CN = "cn"
+    EN = "en"
+
+
 class PackageManager(BaseEnum):
     PIP = "pip"
     POETRY = "poetry"
@@ -39,6 +44,11 @@ class Database(BaseEnum):
     MYSQL = "MySQL"
 
 
+class DBCmd(BaseEnum):
+    MAKEMIGRATIONS = "makemigrations"
+    MIGRATE = "migrate"
+
+
 class VenvCmd(BaseEnum):
     CREATE = "create"
     ON = "on"
