@@ -7,11 +7,11 @@ import pkg_resources
 import typer
 from questionary.form import form
 
-from fastapi_builder.constants import Database, License, PackageManager, PythonVersion, VenvCmd
+from fastapi_builder.constants import Database, Language, License, PackageManager, PythonVersion, DBCmd, VenvCmd
 from fastapi_builder.context import AppContext, ProjectContext
 from fastapi_builder.generator import generate_app, generate_project
-from fastapi_builder.helpers import binary_question, question, text_question
-from fastapi_builder.utils import check_env, read_conf, config_app, set_config_file_content
+from fastapi_builder.helpers import binary_question, question, text_question, snake_to_camel, camel_to_pascal
+from fastapi_builder.utils import check_env, read_conf, config_app, set_config_file_content, new_app_inject_into_project
 
 
 app = typer.Typer(
@@ -25,6 +25,7 @@ app = typer.Typer(
 def startproject(
     name: str,
     interactive: bool = typer.Option(False, help="Run in interactive mode."),
+    language: Optional[Language] = typer.Option("cn", case_sensitive=False),
     database: Optional[Database] = typer.Option("MySQL", case_sensitive=False),
     database_name: Optional[str] = typer.Option(None, "--dbname"),
     docker: bool = typer.Option(False),
@@ -35,6 +36,7 @@ def startproject(
 ):
     if interactive:
         result = form(
+            language=question(Language),
             packaging=question(PackageManager),
             python=question(PythonVersion),
             license=question(License),
@@ -48,6 +50,7 @@ def startproject(
         database_name = database_name if database_name else name
         context = ProjectContext(
             name=name,
+            language=language,
             packaging=packaging,
             python=python,
             license=license_,
@@ -66,10 +69,38 @@ def startapp(
 ):
     # force=False 时，app 必须生成在 project 项目下
     if not (force or "fastapi-builder.ini" in os.listdir()):
-        typer.echo(f"\nFastAPI app must be created under project folder!")
+        typer.echo(f"\nFastAPI app must be created under project root folder!")
         return
     
-    context = AppContext(name=name)
+    # 尝试从配置文件读取 language 信息，使用 try 是因为 force 条件下，不一定存在配置信息
+    try:
+        conf = read_conf("fastapi-builder.ini")
+        language = conf.get("fastapi_builder", "language") or "cn"
+    except:
+        language = "cn"
+    
+    # 生成 app 相关名字
+    folder_name = name.lower().replace(" ", "-").strip()
+    snake_name = folder_name.replace("-", "_")
+    camel_name = snake_to_camel(snake_name)
+    pascal_name = camel_to_pascal(camel_name)
+
+    # 尝试路由自动注入:
+    # 1. 修改 db/base.py 导入 models
+    # 2. 修改 api/routes/api.py 创建路由
+    try:
+        new_app_inject_into_project(folder_name=folder_name, pascal_name=pascal_name, snake_name=snake_name)
+    except:
+        pass
+
+    context = AppContext(
+        name=name,
+        folder_name=folder_name,
+        snake_name=snake_name,
+        camel_name=camel_name,
+        pascal_name=pascal_name,
+        language=language
+    )
     generate_app(context)
 
 
@@ -81,7 +112,7 @@ def run(
 ):
     # 命令必须运行在 project 项目下
     if "fastapi-builder.ini" not in os.listdir():
-        typer.echo(f"\nFastAPI app must run under project folder!")
+        typer.echo(f"\nFastAPI app must run under project root folder!")
         return
     
     # 获取配置文件 conf
@@ -109,6 +140,29 @@ def run(
     subprocess.call(["uvicorn", f"{app_file}:app", *args])
 
 
+@app.command(help="Database migration manager.")
+def db(
+    cmd: DBCmd,
+    migration_message: Optional[str] = typer.Option("create migration", "-m", help="migration message"),
+):
+    # 命令必须运行在 project 项目下
+    if "fastapi-builder.ini" not in os.listdir():
+        typer.echo(f"\n`fastapi db` command must run under project root folder!")
+        return
+
+    # 检查 alembic 是否安装
+    try:
+        subprocess.call(["alembic", "--version"])
+    except:
+        typer.echo(f"\nPlease install alembic correctly first!")
+        return
+    
+    if cmd == DBCmd.MAKEMIGRATIONS:
+        subprocess.call(["alembic", "revision", "--autogenerate", "-m", migration_message])
+    elif cmd == DBCmd.MIGRATE:
+        subprocess.call(["alembic", "upgrade", "head"])
+
+
 @app.command(help="Virtual environment manager.")
 def venv(
     cmd: VenvCmd,
